"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  Blueprints: () => Blueprints,
  camelcase: () => camelcase_exports,
  deepCopy: () => deepCopy,
  exact: () => exact,
  fromJson: () => fromJson,
  isNil: () => isNil,
  mutating: () => mutating,
  snakecase: () => snakecase_exports,
  toJson: () => toJson
});
module.exports = __toCommonJS(src_exports);

// src/operators/index.ts
function fromJson(value, factory) {
  try {
    const entry = JSON.parse(value);
    return factory?.(entry) ?? entry;
  } catch {
  }
}
function toJson(value) {
  try {
    return JSON.stringify(value);
  } catch {
  }
}
function deepCopy(data) {
  if (typeof data === "object") {
    const json = toJson(data);
    if (json) {
      return fromJson(json);
    }
  }
}
var isNil = (value) => value === null || value === void 0;
var exact = (arg) => arg;
var mutating = (arg) => arg;

// src/blueprints/index.ts
var assign = (constructor, args, { validate } = {}) => {
  const blueprint = constructor();
  if (typeof validate === "boolean") {
    const dict = {};
    for (const key in blueprint) {
      if (key in args) {
        blueprint[key] = args[key];
        if (!isNil(blueprint[key])) {
          dict[key] = blueprint[key];
        }
      }
    }
    if (validate && Object.keys(blueprint).length !== Object.keys(dict).length) {
      throw new TypeError("Invalid type");
    }
  } else if (typeof validate === "function") {
    for (const key in blueprint) {
      if (key in args) {
        blueprint[key] = args[key];
      }
    }
    validate(blueprint);
  } else {
    for (const key in blueprint) {
      if (key in args) {
        blueprint[key] = args[key];
      }
    }
  }
  return blueprint;
};
var typeOf = (constructor, args) => {
  const blueprint = constructor();
  if (!blueprint || !args) return false;
  if (Object.keys(blueprint).length !== Object.keys(args).length) return false;
  for (const key in blueprint) {
    if (!(key in args)) return false;
  }
  return true;
};
var difference = (a, b) => {
  const keys = [
    ...new Set([].concat(
      Object.keys(a).filter((k) => !(k in b)),
      Object.keys(b).filter((k) => !(k in a))
    ))
  ].sort();
  const dict = {};
  for (const key of keys) {
    if (key in a) dict[key] = a[key];
    else dict[key] = b[key];
  }
  return dict;
};
var intersection = (a, b) => {
  const keys = [
    ...new Set([].concat(
      Object.keys(a).filter((k) => k in b),
      Object.keys(b).filter((k) => k in a)
    ))
  ].sort();
  const dict = {};
  for (const key of keys) {
    dict[key] = a[key];
    dict[key] = b[key];
  }
  return dict;
};
var merge = (a, b) => {
  const keys = [
    ...new Set([].concat(
      Object.keys(a),
      Object.keys(b)
    ))
  ].sort();
  const dict = {};
  for (const key of keys) {
    if (key in a) dict[key] = a[key];
    if (key in b) dict[key] = b[key];
  }
  return dict;
};
var Blueprints = Object.freeze({
  assign,
  typeOf,
  difference,
  intersection,
  merge
});

// src/camelcase/index.ts
var camelcase_exports = {};

// src/snakecase/index.ts
var snakecase_exports = {};
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  Blueprints,
  camelcase,
  deepCopy,
  exact,
  fromJson,
  isNil,
  mutating,
  snakecase,
  toJson
});
