// src/operators/index.ts
function fromJson(value, factory) {
  try {
    const entry = JSON.parse(value);
    return factory?.(entry) ?? entry;
  } catch {
  }
}
function toJson(value) {
  try {
    return JSON.stringify(value);
  } catch {
  }
}
function deepCopy(data) {
  if (typeof data === "object") {
    const json = toJson(data);
    if (json) {
      return fromJson(json);
    }
  }
}
var isNil = (value) => value === null || value === void 0;
var exact = (arg) => arg;
var mutating = (arg) => arg;

// src/blueprints/index.ts
var assign = (constructor, args, { validate } = {}) => {
  const blueprint = constructor();
  if (typeof validate === "boolean") {
    const dict = {};
    for (const key in blueprint) {
      if (key in args) {
        blueprint[key] = args[key];
        if (!isNil(blueprint[key])) {
          dict[key] = blueprint[key];
        }
      }
    }
    if (validate && Object.keys(blueprint).length !== Object.keys(dict).length) {
      throw new TypeError("Invalid type");
    }
  } else if (typeof validate === "function") {
    for (const key in blueprint) {
      if (key in args) {
        blueprint[key] = args[key];
      }
    }
    validate(blueprint);
  } else {
    for (const key in blueprint) {
      if (key in args) {
        blueprint[key] = args[key];
      }
    }
  }
  return blueprint;
};
var typeOf = (constructor, args) => {
  const blueprint = constructor();
  if (!blueprint || !args) return false;
  if (Object.keys(blueprint).length !== Object.keys(args).length) return false;
  for (const key in blueprint) {
    if (!(key in args)) return false;
  }
  return true;
};
var difference = (a, b) => {
  const keys = [
    ...new Set([].concat(
      Object.keys(a).filter((k) => !(k in b)),
      Object.keys(b).filter((k) => !(k in a))
    ))
  ].sort();
  const dict = {};
  for (const key of keys) {
    if (key in a) dict[key] = a[key];
    else dict[key] = b[key];
  }
  return dict;
};
var intersection = (a, b) => {
  const keys = [
    ...new Set([].concat(
      Object.keys(a).filter((k) => k in b),
      Object.keys(b).filter((k) => k in a)
    ))
  ].sort();
  const dict = {};
  for (const key of keys) {
    dict[key] = a[key];
    dict[key] = b[key];
  }
  return dict;
};
var merge = (a, b) => {
  const keys = [
    ...new Set([].concat(
      Object.keys(a),
      Object.keys(b)
    ))
  ].sort();
  const dict = {};
  for (const key of keys) {
    if (key in a) dict[key] = a[key];
    if (key in b) dict[key] = b[key];
  }
  return dict;
};
var Blueprints = Object.freeze({
  assign,
  typeOf,
  difference,
  intersection,
  merge
});

// src/camelcase/index.ts
var camelcase_exports = {};

// src/snakecase/index.ts
var snakecase_exports = {};
export {
  Blueprints,
  camelcase_exports as camelcase,
  deepCopy,
  exact,
  fromJson,
  isNil,
  mutating,
  snakecase_exports as snakecase,
  toJson
};
